yakumo.nova.v2.agent

Package yakumo :: Package nova :: Package v2 :: Module agent |
[hide private]
[frames] | no frames]

# Module agent

source code

Resource class and its manager for agents in Compute API v2

Classes | [hide private]
| Resource Resource class for agents in Compute API v2
| Manager Manager class for agents in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``agent_id``'``,` <yakumo.mapper.NoopCla`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id',
        'agent_id',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('architecture',
        'architecture',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('hypervisor',
        'hypervisor',
      ...